@@ -395,19 +395,19 @@ class TemplateConfigurationLinuxVolume(NetBoxModel):
         on_delete=models.CASCADE,
         related_name='platform_template_configuration',
     )
-    linux_volume = models.ForeignKey(
-        MountedVolume,
+    drive = models.ForeignKey(
+        Drive,
         on_delete=models.CASCADE,
-        related_name='linux_volume_template_configuration'
+        related_name='drive_template_configuration'
     )
 
     clone_fields = [
-        "linux_volume",
-        "platform"
+        "platform",
+        "drive"
     ]
 
     class Meta:
-        ordering = ["linux_volume", "platform"]
+        ordering = ["platform", "drive"]
 
     # def get_absolute_url(self):
     #     return reverse("plugins:netbox_storage:storageconfiguration", kwargs={"pk": self.pk})
