@@ -47,11 +47,12 @@ class TemplateVolumeConfig(PluginTemplateExtension):
         obj = self.context.get("object")
 
         lv = LogicalVolume.objects.all()
-        drives = TemplateConfigurationLinuxVolume.objects.filter(platform=obj).values_list('drive')
+        drives = TemplateConfigurationLinuxVolume.objects.values('drive').filter(platform=obj)
         print("template content")
         print(drives)
         for d in drives:
-            print(d)
+            print(d.size)
+            print(d.drive)
 
 
         # storage_configuration = StorageConfigurationLinuxVolume.objects.filter(virtual_machine=obj)
