@@ -1,7 +1,7 @@
 from netbox.views import generic
 
 from netbox_storage.forms import LVMSimpleForm, VolumeSimpleForm, LinuxVolumeSimpleForm
-from netbox_storage.forms.template import LinuxVolumeTemplateForm, LVMTemplateForm
+from netbox_storage.forms.template import LinuxVolumeTemplateForm, LVMTemplateForm, DriveTemplateForm
 from netbox_storage.models import Drive, StorageConfigurationLinuxVolume, TemplateConfigurationLinuxVolume
 
 
@@ -20,3 +20,8 @@ class AddTemplateVolumeView(generic.ObjectEditView):
     form = LinuxVolumeTemplateForm
 #    default_return_url = "plugins:netbox_storage:drive_list"
     # default_return_url = "virtualization:virtualmachine"
+
+
+class AddTemplateDriveView(generic.ObjectEditView):
+    queryset = TemplateConfigurationLinuxVolume.objects.all()
+    form = DriveTemplateForm
